/*  ESP32_WebServer_twoled
 *   
 *  Egyszerű webszerver mintapélda, amelyben két LED-et kapcsolhatunk
 *  a web böngészőből (LED1 a GPIO22, LED2 a GPIO23 lábakra kötve).
 *  
 *  A program eredeti változata a Last Minute Engineers honlapon 
 *  található. két változatban (AP és STA módban)
 *  Create A Simple ESP32 Web Server In Arduino IDE
 *  Link: https://lastminuteengineers.com/creating-esp32-web-server-arduino-ide/
 *
 *  Mi az 'ESP32 as HTTP Server using WiFi Station (STA) mode'
 *  című második változatot vettük át, kissé módosítva:
 *   - A LED-eket más GPIO lábakra kötöttük
 *   - A nyitólapon nem kapcsoljuk le a LED-eket, mint az eredetiben
 *   - A hibejelzéshez HTML lapot készítettünk egy nyomógombbal, 
 *     amely megnyomáskor a nyitóoldalra visz vissza
 *     
 * Tested with Arduini IDE 1.8.19 and ESP32 Arduino Core 2.0.2    
 */

#include <WiFi.h>
#include <AsyncTCP.h>                  // https://github.com/me-no-dev/AsyncTCP
#include <ESPAsyncWebServer.h>         // https://github.com/me-no-dev/ESPAsyncWebServer
#include "secrets.h"
#include "index.h"

AsyncWebServer server(80);             // Webszerver objektumpéldány létrehozása     

uint8_t LED1pin = 22;
bool LED1status = LOW;

uint8_t LED2pin = 23;
bool LED2status = LOW;

void setup() {
  Serial.begin(115200);
  delay(100);
  pinMode(LED1pin, OUTPUT);
  pinMode(LED2pin, OUTPUT);
  setup_wifi();
  server.on("/", handle_OnConnect);
  server.on("/led1on", handle_led1on);
  server.on("/led1off", handle_led1off);
  server.on("/led2on", handle_led2on);
  server.on("/led2off", handle_led2off);
  server.onNotFound(handle_NotFound);
  server.begin();
  Serial.println("HTTP server started");
}

void loop() {
  if (LED1status)
  { digitalWrite(LED1pin, HIGH); }
  else
  { digitalWrite(LED1pin, LOW);  }

  if (LED2status)
  { digitalWrite(LED2pin, HIGH); }
  else
  { digitalWrite(LED2pin, LOW);  }
}

String processor(const String& var)
{
  if(var == "LED1BTN") {
    if(LED1status) return F("<p>LED1 Status: ON</p><a class=\"button button-off\" href=\"/led1off\">OFF</a>\n");
    else return F("<p>LED1 Status: OFF</p><a class=\"button button-on\" href=\"/led1on\">ON</a>\n");
  }
  if(var == "LED2BTN") {
    if(LED2status) return F("<p>LED2 Status: ON</p><a class=\"button button-off\" href=\"/led2off\">OFF</a>\n");
    else return F("<p>LED2 Status: OFF</p><a class=\"button button-on\" href=\"/led2on\">ON</a>\n");
  }
  return String();
}


void handle_OnConnect(AsyncWebServerRequest *request) {
  LED1status = false;
  LED2status = false;
  Serial.println("GPIO22 Status: OFF | GPIO23 Status: OFF");
  request->send_P(200, "text/html", index_html, processor);
}

void handle_led1on(AsyncWebServerRequest *request) {
  LED1status = true;
  Serial.println("GPIO22 Status: ON");
  request->send_P(200, "text/html", index_html, processor);
}

void handle_led1off(AsyncWebServerRequest *request) {
  LED1status = false;
  Serial.println("GPIO22 Status: OFF");
  request->send_P(200, "text/html", index_html, processor);
}

void handle_led2on(AsyncWebServerRequest *request) {
  LED2status = true;
  Serial.println("GPIO23 Status: ON");
  request->send_P(200, "text/html", index_html, processor);
}

void handle_led2off(AsyncWebServerRequest *request) {
  LED2status = false;
  Serial.println("GPIO23 Status: OFF");
  request->send_P(200, "text/html", index_html, processor);
}

void handle_NotFound(AsyncWebServerRequest *request) {
  request->send_P(404, "text/html", error_html);
}  

void setup_wifi() {
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}
