/* ESP32_ledswitch_ajax
 *     
 * Based on the ESP8266 NodeMCU AJAX Demo
 * Updates and Gets data from webpage without page refresh
 * https://circuits4you.com/2018/02/04/esp8266-ajax-update-part-of-web-page-without-refreshing/
 */
#include <WiFi.h>
#include <WebServer.h>
#include "secrets.h"
#include "index.h"                 //Our HTML webpage contents with javascripts

#define LED 2                      //On board LED (anode driven)

WebServer server(80);              //Server on port 80

//===============================================================
// ESP32 connects to local network
//===============================================================
void setup_wifi() {
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}


//===============================================================
// This routine is executed when you open its IP in browser
//===============================================================
void handleRoot() {
  String s = FPSTR(MAIN_page);      //Read HTML contents from flash
  server.send(200, "text/html", s); //Send web page
}

void handleADC() {
  float v = (analogRead(34)+80)/1239.0f;    // Measure voltage az GPIO34
  String adcValue = String(v,3);
  server.send(200, "text/plain", adcValue); //Send ADC value only to client ajax request
}

void handleLED() {
  String ledState = "OFF";
  String t_state = server.arg("LEDstate"); //Refer  xhttp.open("GET", "setLED?LEDstate="+led, true);
  Serial.println(t_state);
  if (t_state == "1") {
    digitalWrite(LED, HIGH);         //LED ON
    ledState = "ON";                 //Feedback parameter
  }
  else  {
    digitalWrite(LED, LOW);          //LED OFF
    ledState = "OFF";                //Feedback parameter
  }
  server.send(200, "text/plain", ledState); //Send web page
}

//==============================================================
//                  SETUP
//==============================================================
void setup(void) {
  Serial.begin(115200);  
  analogReadResolution(12);          // 12-bit felbontás
  analogSetAttenuation(ADC_11db);    // Méréshatár 0-3,3 V
  setup_wifi();
  //Onboard LED port Direction output
  pinMode(LED, OUTPUT);
  server.on("/", handleRoot);        // This is display page
  server.on("/setLED", handleLED);   // Serve LED requests
  server.on("/readADC", handleADC);  // Serve ADC requests
  server.begin();                  //Start server
  Serial.println("HTTP server started");
}

//==============================================================
//                     LOOP
//==============================================================
void loop(void) {
  server.handleClient();          //Handle client requests
}
